<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet
        version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
        xmlns:err="urn:customs.ru:Information:ExchangeDocuments:ErrorList:5.4.0" xmlns:cat_ru="urn:customs.ru:CommonAggregateTypes:5.4.0"
        xmlns="http://www.w3.org/1999/xhtml">

    <xsl:output media-type="text/html" method="html" encoding="UTF-8" omit-xml-declaration="yes"
                doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
                doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd" indent="yes" version="1.0"/>

    <xsl:template match="/">
        <html>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
                <title>Перечень ошибок, выявленных в процессе проведения форматно-логического контроля сведений, заявленных в электронной форме документа</title>
                <style type="text/css">
                    body {background-color: #cccccc;}

                    div.page {
                        width: 210mm;
                        margin: 6pt auto;
                        padding: 10mm;
                        background: white;
                        border: solid 1px black;
                    }

                    /*Стиль для удаления чёрной границы вокруг нарисованной "страницы"  при печати*/
                    @media print {div.page {border: none; margin: 0; padding: 0;}}

                    h1 {
                        text-align: center;
                        font-size: 16pt;
                        margin-bottom: 10pt;
                        counter-reset: document;
                    }

                    h2:before {
                        content: counter(document) ". ";
                        counter-increment: document;
                    }

                    h2 {
                        font-size: 14pt;
                        counter-reset: error;
                        text-align: center;
                        margin-top: 20pt;
                    }

                    h3:before {
                        content: counter(document) "." counter(error) ". ";
                        counter-increment: error;
                    }

                    h3 {font-size: 13pt;}

                    span {font-weight: bold;}

                    p {padding-left: 10pt;}
                </style>
            </head>
            <body>
                <div class="page">
                    <xsl:apply-templates select="err:ErrorList"/>
                </div>
            </body>
        </html>
    </xsl:template>

    <!--Основной шаблон. Обрабатываем корневой элемент-->
    <xsl:template match="err:ErrorList">
        <h1>Перечень ошибок, выявленных в процессе проведения форматно-логического контроля сведений, заявленных в электронной форме документа</h1>

        <p>
            <xsl:apply-templates select="err:Customs"/>
            <br/>
            <span>Дата направления: </span>
            <xsl:call-template name="DateRu"><xsl:with-param name="text" select="err:SendDate"/></xsl:call-template>
        </p>

        <xsl:apply-templates select="err:BadDocument"/>
    </xsl:template>

    <xsl:template match="err:Customs">
        <span>Таможенный орган: </span>
        <xsl:apply-templates select="cat_ru:Code"/>
        <xsl:if test="cat_ru:OfficeName"><xsl:text>, </xsl:text><xsl:apply-templates select="cat_ru:OfficeName"/></xsl:if>
    </xsl:template>

    <xsl:template match="err:BadDocument">
        <h2>Документ с ошибками. Уникальный идентификатор: <xsl:value-of select="err:DocID"/></h2>
        <xsl:if test="err:DocName | err:DocModeID">
            <p><xsl:apply-templates select="err:DocName | err:DocModeID"/></p>
        </xsl:if>

        <xsl:apply-templates select="err:Error"/>
    </xsl:template>

    <xsl:template match="err:DocName">
        <span>Название: </span>
        <xsl:value-of select="."/>
    </xsl:template>

    <xsl:template match="err:DocModeID">
        <xsl:call-template name="LineBreakSeparator"/>
        <span>Код вида документа  (значение атрибута DocumentModeID): </span>
        <xsl:value-of select="."/>
    </xsl:template>

    <xsl:template match="err:Error">
        <h3>Ошибка: "<xsl:apply-templates select="err:ErrorName"/>"</h3>
        <p>
            <span>Дата и время обнаружения: </span>
            <xsl:call-template name="DateRu"><xsl:with-param name="text" select="err:DateInf"/></xsl:call-template>
            <xsl:text>, </xsl:text>
            <xsl:call-template name="Time"><xsl:with-param name="text" select="err:TimeInf"/></xsl:call-template>

            <br/>
            <span>Код ошибки: </span>
            <xsl:value-of select="err:ErrCode"/>
            <span>, уровень: </span>
            <xsl:value-of select="err:ErrLevel"/>
            <xsl:if test="err:ErrField">
                <span>, номер графа ДТ/ДТС/КТС: </span>
                <xsl:value-of select="err:ErrField"/>
            </xsl:if>
            <xsl:if test="err:GTDGoodsNumber">
                <span>, номер товара по ДТ/списку: </span>
                <xsl:value-of select="err:GTDGoodsNumber"/>
            </xsl:if>
            <xsl:if test="err:ErrElement">
                <br/>
                <span>Имя ошибочного узла/элемента/атрибута: </span>
                <xsl:value-of select="err:ErrElement"/>
            </xsl:if>
            <xsl:if test="err:ErrElementDesc">
                <br/>
                <span>Описание поля, в котором найдена ошибка: </span>
                <xsl:value-of select="err:ErrElementDesc"/>
            </xsl:if>
            <xsl:if test="err:SuccessContent">
                <br/>
                <span>Верное значение: </span>
                <xsl:value-of select="err:SuccessContent"/>
            </xsl:if>
            <xsl:if test="err:CorrectValue">
                <br/>
                <span>Верное (ожидаемое) значение: </span>
                <xsl:value-of select="err:CorrectValue"/>
            </xsl:if>
            <xsl:if test="err:CodeOrder">
                <br/>
                <span>Код нормативного документа: </span>
                <xsl:value-of select="err:CodeOrder"/>
            </xsl:if>
            <xsl:if test="err:ErrDescription">
                <br/>
                <span>Подробное описание ошибки: </span>
                <xsl:apply-templates select="err:ErrDescription"/>
            </xsl:if>
        </p>
    </xsl:template>

    <!--Добавляем перевод на новую строку, если в этой уже был выведен другой элемент-->
    <xsl:template name="LineBreakSeparator">
        <xsl:if test="position() > 1"><br/></xsl:if>
    </xsl:template>

    <!--Дата по стандарту русской локали-->
    <xsl:template name="DateRu">
        <xsl:param name="text"/>
        <xsl:choose>
            <xsl:when test="substring($text, 5, 1) = '-' and substring($text, 8, 1) = '-'">
                <!--Текст для разбора даты имеет верный формат - разбираем посимвольно-->
                <xsl:value-of select="substring($text, 9, 2)"/>
                <xsl:text>.</xsl:text>
                <xsl:value-of select="substring($text, 6, 2)"/>
                <xsl:text>.</xsl:text>
                <xsl:value-of select="substring($text, 1, 4)"/>
                <xsl:text> г.</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <!--Текст для разбора даты имеет неверный формат - выводим текст в исходном виде-->
                <xsl:value-of select="$text"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!--Форматирует время для отображения-->
    <xsl:template name="Time">
        <xsl:param name="text"/>
        <xsl:value-of select="substring($text, 1, 8)"/>
    </xsl:template>
</xsl:stylesheet>
